@@ -147,7 +147,7 @@ Gets the count of opens in this series.
 
 =head1 AUTHOR
 
-Cory 'G' Watson <gphat@cpan.org>
+Cory G Watson <gphat@cpan.org>
 
 =head1 LICENSE
 
